==> contour-ai-sdk-1.2.0.tgz: package/ios/ContourAiSdk.mm <==
#import "ContourAiSdk.h"

@implementation ContourAiSdk
RCT_EXPORT_MODULE()

- (NSArray<NSString *> *)supportedEvents {
    return @[@"checkCaptured"];
}

RCT_REMAP_METHOD(startContourSDK,
                 CapturingSide:(NSString *)captureSide withClientId:(NSString *)clientID withCaptureType:(NSString *)captureType withEnableMultipleCheckCapturing:(BOOL) enableMultipleCheckCapturing ) {
    [self openContoursSDK:captureSide withClientId:clientID withCaptureType:captureType withEnableMultipleCheckCapturing:enableMultipleCheckCapturing];
}

-(void)openContoursSDK:(NSString *)captureSide withClientId:(NSString *)clientID withCaptureType:(NSString *)captureType withEnableMultipleCheckCapturing:(BOOL) enableMultipleCheckCapturing {
    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, 0.1 * NSEC_PER_SEC), dispatch_get_main_queue(), ^{
        [self removeFile];
        UINavigationController *navController = (UINavigationController *)[[[UIApplication sharedApplication] keyWindow] rootViewController];
        ContoursAIFramework *contourCaptureViewController = [[ContoursAIFramework alloc] init];
        UIViewController *vc = [contourCaptureViewController initializeSDKWithCheckCapturingSide:captureSide clientId:clientID captureType:captureType enableMultipleCheckCapturing:YES delegate:self];
        NSNumber *value = [NSNumber numberWithInt:UIDeviceOrientationLandscapeRight];
        [[UIDevice currentDevice] setValue:value forKey:@"orientation"];
        [navController pushViewController:vc animated:YES];
    });
}

- (void)imageCapturedWithFrontImageCropped:(UIImage *)frontImageCropped rearImageCropped:(UIImage *)rearImageCropped frontImage:(UIImage *)frontImage rearImage:(UIImage *)rearImage {
    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, 0.2 * NSEC_PER_SEC), dispatch_get_main_queue(), ^{
        //Creating data
        NSMutableDictionary *dataObject = [NSMutableDictionary dictionary];
        NSString *filePathFront = [self addFileToDirectoryFileName:@"contourFront.jpeg" image:frontImage];
        NSString *filePathRear = [self addFileToDirectoryFileName:@"contourRear.jpeg" image:rearImage];
        NSString *filePathFrontCropped = [self addFileToDirectoryFileName:@"contourFrontCropped.jpeg" image:frontImageCropped];
        NSString *filePathRearCropped = [self addFileToDirectoryFileName:@"contourRearCropped.jpeg" image:rearImageCropped];
        
        [dataObject setValue:filePathFront forKey:@"frontUri"];
        [dataObject setValue:filePathRear forKey:@"rearUri"];
        [dataObject setValue:filePathFrontCropped forKey:@"croppedFrontUri"];
        [dataObject setValue:filePathRearCropped forKey:@"croppedRearUri"];
        [self sendEventWithName:@"checkCaptured" body: dataObject];
    });
}

// Adding the image in NSTemporaryDirectory.
- (NSString *) addFileToDirectoryFileName:(NSString *)fileName image:(UIImage *)image{
    [[NSFileManager defaultManager] createDirectoryAtPath:[NSTemporaryDirectory() stringByAppendingPathComponent:@"contourTemp"]
                              withIntermediateDirectories:YES attributes:nil error:nil];
    
    long milliseconds = (long)([[NSDate date] timeIntervalSince1970]);
    NSString *timestamp = [NSString stringWithFormat:@"%ld", milliseconds];
    NSString *fullFileName = [NSString stringWithFormat:@"%@_%@", timestamp,fileName];
    NSString *documentsDirectory = NSTemporaryDirectory();
    NSString *filePath = [NSString stringWithFormat:@"%@contourTemp/%@", documentsDirectory, fullFileName];
    NSData* imageData = UIImageJPEGRepresentation(image,1);
    [imageData writeToFile:filePath options:YES error:nil];
    return filePath;
}

// Deleting the image if image is saved for more than one Day.
- (void) removeFile {
    NSArray* tmpDirectory = [[NSFileManager defaultManager] contentsOfDirectoryAtPath:[NSTemporaryDirectory() stringByAppendingPathComponent:@"/contourTemp"] error:NULL];
    for (NSString *file in tmpDirectory) {
        NSString *timeStamp = [file componentsSeparatedByString:@"_"][0];
        double timestampDouble = [timeStamp doubleValue];
        long currentTimestamp = (long)([[NSDate date] timeIntervalSince1970]);
        NSTimeInterval difference = [[NSDate dateWithTimeIntervalSince1970:currentTimestamp] timeIntervalSinceDate:[NSDate dateWithTimeIntervalSince1970:timestampDouble]];
        int numberOfDays = difference / 86400;
        if (numberOfDays >= 1) {
            NSString *filePath = [NSString stringWithFormat:@"%@/contourTemp/%@", NSTemporaryDirectory(), file];
            [[NSFileManager defaultManager] removeItemAtPath:filePath error:NULL];
        }
        NSLog(@"There are %d days in between the two dates.", numberOfDays);
    }
}
// Don't compile this code when we build for the old architecture.
#ifdef RCT_NEW_ARCH_ENABLED
- (std::shared_ptr<facebook::react::TurboModule>)getTurboModule:
    (const facebook::react::ObjCTurboModule::InitParams &)params
{
    return std::make_shared<facebook::react::NativeContourAiSdkSpecJSI>(params);
}
#endif

@end

==> contour-ai-sdk-1.2.1.tgz: package/ios/ContourAiSdk.mm <==
#import "ContourAiSdk.h"

@implementation ContourAiSdk
RCT_EXPORT_MODULE()

- (NSArray<NSString *> *)supportedEvents {
    return @[@"checkCaptured"];
}

RCT_REMAP_METHOD(startContourSDK,
                 CapturingSide:(NSString *)captureSide withClientId:(NSString *)clientID withCaptureType:(NSString *)captureType withEnableMultipleCheckCapturing:(BOOL) enableMultipleCheckCapturing ) {
    [self openContoursSDK:captureSide withClientId:clientID withCaptureType:captureType withEnableMultipleCheckCapturing:enableMultipleCheckCapturing];
}

-(void)openContoursSDK:(NSString *)captureSide withClientId:(NSString *)clientID withCaptureType:(NSString *)captureType withEnableMultipleCheckCapturing:(BOOL) enableMultipleCheckCapturing {
    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, 0.1 * NSEC_PER_SEC), dispatch_get_main_queue(), ^{
        [self removeFile];
        UINavigationController *navController = (UINavigationController *)[[[UIApplication sharedApplication] keyWindow] rootViewController];
        ContoursAIFramework *contourCaptureViewController = [[ContoursAIFramework alloc] init];
        UIViewController *vc = [contourCaptureViewController initializeSDKWithCheckCapturingSide:captureSide clientId:clientID captureType:captureType enableMultipleCheckCapturing:enableMultipleCheckCapturing delegate:self];
        NSNumber *value = [NSNumber numberWithInt:UIDeviceOrientationLandscapeRight];
        [[UIDevice currentDevice] setValue:value forKey:@"orientation"];
        [navController pushViewController:vc animated:YES];
    });
}

- (void)imageCapturedWithFrontImageCropped:(UIImage *)frontImageCropped rearImageCropped:(UIImage *)rearImageCropped frontImage:(UIImage *)frontImage rearImage:(UIImage *)rearImage {
    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, 0.2 * NSEC_PER_SEC), dispatch_get_main_queue(), ^{
        //Creating data
        NSMutableDictionary *dataObject = [NSMutableDictionary dictionary];
        NSString *filePathFront = [self addFileToDirectoryFileName:@"contourFront.jpeg" image:frontImage];
        NSString *filePathRear = [self addFileToDirectoryFileName:@"contourRear.jpeg" image:rearImage];
        NSString *filePathFrontCropped = [self addFileToDirectoryFileName:@"contourFrontCropped.jpeg" image:frontImageCropped];
        NSString *filePathRearCropped = [self addFileToDirectoryFileName:@"contourRearCropped.jpeg" image:rearImageCropped];
        
        [dataObject setValue:filePathFront forKey:@"frontUri"];
        [dataObject setValue:filePathRear forKey:@"rearUri"];
        [dataObject setValue:filePathFrontCropped forKey:@"croppedFrontUri"];
        [dataObject setValue:filePathRearCropped forKey:@"croppedRearUri"];
        [self sendEventWithName:@"checkCaptured" body: dataObject];
    });
}

// Adding the image in NSTemporaryDirectory.
- (NSString *) addFileToDirectoryFileName:(NSString *)fileName image:(UIImage *)image{
    [[NSFileManager defaultManager] createDirectoryAtPath:[NSTemporaryDirectory() stringByAppendingPathComponent:@"contourTemp"]
                              withIntermediateDirectories:YES attributes:nil error:nil];
    
    long milliseconds = (long)([[NSDate date] timeIntervalSince1970]);
    NSString *timestamp = [NSString stringWithFormat:@"%ld", milliseconds];
    NSString *fullFileName = [NSString stringWithFormat:@"%@_%@", timestamp,fileName];
    NSString *documentsDirectory = NSTemporaryDirectory();
    NSString *filePath = [NSString stringWithFormat:@"%@contourTemp/%@", documentsDirectory, fullFileName];
    NSData* imageData = UIImageJPEGRepresentation(image,1);
    [imageData writeToFile:filePath options:YES error:nil];
    return filePath;
}

// Deleting the image if image is saved for more than one Day.
- (void) removeFile {
    NSArray* tmpDirectory = [[NSFileManager defaultManager] contentsOfDirectoryAtPath:[NSTemporaryDirectory() stringByAppendingPathComponent:@"/contourTemp"] error:NULL];
    for (NSString *file in tmpDirectory) {
        NSString *timeStamp = [file componentsSeparatedByString:@"_"][0];
        double timestampDouble = [timeStamp doubleValue];
        long currentTimestamp = (long)([[NSDate date] timeIntervalSince1970]);
        NSTimeInterval difference = [[NSDate dateWithTimeIntervalSince1970:currentTimestamp] timeIntervalSinceDate:[NSDate dateWithTimeIntervalSince1970:timestampDouble]];
        int numberOfDays = difference / 86400;
        if (numberOfDays >= 1) {
            NSString *filePath = [NSString stringWithFormat:@"%@/contourTemp/%@", NSTemporaryDirectory(), file];
            [[NSFileManager defaultManager] removeItemAtPath:filePath error:NULL];
        }
        NSLog(@"There are %d days in between the two dates.", numberOfDays);
    }
}
// Don't compile this code when we build for the old architecture.
#ifdef RCT_NEW_ARCH_ENABLED
- (std::shared_ptr<facebook::react::TurboModule>)getTurboModule:
    (const facebook::react::ObjCTurboModule::InitParams &)params
{
    return std::make_shared<facebook::react::NativeContourAiSdkSpecJSI>(params);
}
#endif

@end
